// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Table value
class TableValue extends TableField {
  /// Array value
  ///
  /// An array value can store multiple values of the specified data type.
  final bool array;

  /// Properties map
  ///
  /// The properties map allows you to extend fields beyond the limits of data
  /// classes. The properties map can be used to find data fields that match
  /// certain requirements. For example, if you want moldata that is optimized
  /// using an MMFF94 energy minimization, you can search for a field that has
  /// this property in its property map.
  final Map<String, String> properties;

  /// Constructor
  const TableValue(
      DataType dataType, String dataClass, this.array, this.properties)
      : super(dataType, dataClass);

  /// Construct from PDS.
  factory TableValue.fromPds(Map<String, dynamic> data) {
    return new TableValue(
        DataType.values[data['type'] as int],
        data['class'] as String,
        data['array'] as bool,
        data['properties'] as Map<String, String>);
  }

  /// Convert to PDS.
  Map<String, dynamic> toPds() {
    return {
      'type': dataType.index,
      'class': dataClass,
      'array': array,
      'properties': pdsFromMap(properties)
    };
  }
}
